package com.jobs.controller;

import com.jobs.domain.Employee;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.core.env.Environment;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.Arrays;
import java.util.List;

@RestController
public class TestController {

    //------------------------------------------
    //通过 @Value 注解获取 yml 中配置的值

    @Value("${name}")
    private String name;

    @Value("${age}")
    private int age;

    //使用英文逗号分隔的字符串，可以直接转换为数组
    @Value("${hobby}")
    private String[] hobby;

    @Value("${employee.name}")
    private String e_name;

    @Value("${employee.age}")
    private int e_age;

    //通过 @Value 注解，对于使用横杠表示的数组，无法直接获取整个数组
    //只能通过数组的下标，获取具体的一个数组元素
    @Value("${employee.hobby[0]}")
    private String e_hobby0;


    @RequestMapping("/getdata1")
    public String getData1() {
        //通过 @Value 注解，获取 yml 配置文件中的对应名称的值
        StringBuilder sb = new StringBuilder();
        sb.append(name).append("<br/>");
        sb.append(age).append("<br/>");
        sb.append(Arrays.toString(hobby)).append("<br/>");
        sb.append(e_name).append("<br/>");
        sb.append(e_age).append("<br/>");
        sb.append(e_hobby0);
        System.out.println(sb.toString().replace("<br/>","\n"));
        return sb.toString();
    }


    //------------------------------------------
    //通过 Environment 环境对象，获取 yml 中配置的值

    @Autowired
    private Environment env;

    @RequestMapping("/getdata2")
    public String getData2()
    {
        //通过 Environment 环境对象，获取 yml 中配置的值
        String name2 = env.getProperty("name");
        String e_name2 = env.getProperty("employee.name");
        System.out.println(name2);
        System.out.println(e_name2);

        //在 yml 的配置中，可以通过 ${变量名} 引用大括号中的变量所配置的值
        String remark1 = env.getProperty("remark1");
        String remark2 = env.getProperty("remark2");
        //对于单引号包裹的字符串，不会处理转义字符
        System.out.println(remark1);
        //对于双引号包裹的字符串，会对转义字符进行处理
        System.out.println(remark2);

        return "请在 IDEA 控制台上，查看运行结果";
    }


    //------------------------------------------
    //通过实体对象，获取 yml 中配置的值，需要创建一个实体类与 yml 中相关配置节对应

    //在实体类中，可以获取到横杠配置的数组
    @Autowired
    private Employee emp;

    @RequestMapping("/getdata3")
    public String getData3()
    {
        System.out.println(emp);
        System.out.println("姓名："+emp.getName());
        System.out.println("年龄："+emp.getAge());
        System.out.println("爱好："+Arrays.toString(emp.getHobby()));
        return "请从 IDEA 的控制台，查看通过实体类对象获取的 yml 配置值";
    }
}
